@@ -8,4 +8,4 @@ except ModuleNotFoundError:
     from .aggregation import aggregate
     from .amalgamation import amalgamate
     print("Cython fail.")
-from .classix import Clustering as classix
\ No newline at end of file
+from .clustering import classix
\ No newline at end of file
